==> haskell-unicode-collation-0.1.3.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-collation
version:              0.1.3.2
visibility:           public
id:                   unicode-collation-0.1.3.2-1FDOJq2wWTQ2uGpeNCFkcA
key:                  unicode-collation-0.1.3.2-1FDOJq2wWTQ2uGpeNCFkcA
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  b3fb6268f1c200f518b2893ef6aecb65
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unicode-collation-0.1.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unicode-collation-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-collation
hs-libraries:         HSunicode-collation-0.1.3.2-1FDOJq2wWTQ2uGpeNCFkcA
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 parsec-3.1.14.0 template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-instances-0.1.19-B9gWRZ8PyCw5uxRT7DNRnQ

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-collation-0.1.3.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-collation
version:              0.1.3.2
visibility:           public
id:                   unicode-collation-0.1.3.2-LnIdqoMj7Bs8KG9Dk3KDBh
key:                  unicode-collation-0.1.3.2-LnIdqoMj7Bs8KG9Dk3KDBh
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  54e7eca18235c1d6d034f11207248372
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unicode-collation-0.1.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unicode-collation-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-collation
hs-libraries:         HSunicode-collation-0.1.3.2-LnIdqoMj7Bs8KG9Dk3KDBh
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 parsec-3.1.14.0 template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-instances-0.1.19-5VDm8NGCgu2JjiKApqMXF

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
